@@ -38,7 +38,7 @@ class AudioData():
 
 # Range for each note
 conversion = [(10000.0,1077.0,"r"),
-			(1077.0,1017.1,"c''"),
+			(1077.0,1017.1,"c'''"),
 			(1017.0,960.0,"b''"),	
 			(960.0,906.2,"ais''"),
 			(906.2,855.3,"a''"),
